==> openjdk-17_17.0.18+8.orig.tar.xz: openjdk-17-17.0.18+8/test/jdk/tools/jlink/plugins/SystemModuleDescriptors/src/com.foo/com/foo/Main.java <==
/*
 * Copyright (c) 2024, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package com.foo;

import java.lang.module.ModuleDescriptor;
import java.lang.module.ModuleFinder;
import java.util.stream.Stream;

/**
 * Sanity test if SystemModules pre-resolved at link-time for com.foo
 * with main class is loaded properly.
 */
public class Main {
    public static void main(String... args) throws Exception {
        ModuleDescriptor md = Main.class.getModule().getDescriptor();
        System.out.println(md);

        checkMainClass("com.foo", "com.foo.Main");
        checkMainClass("net.foo", "net.foo.Main");
    }

    static void checkMainClass(String mn, String mainClass) {
        String cn = ModuleFinder.ofSystem().find(mn).get().descriptor().mainClass().get();
        if (!cn.equals(mainClass)) {
            throw new RuntimeException("Mismatched main class of module " + mn + ": " + cn + " expected: " + mainClass);
        }
    }
}

==> openjdk-21_21.0.9+10.orig.tar.xz: openjdk-21-21.0.9+10/test/jdk/tools/jlink/plugins/SystemModuleDescriptors/src/com.foo/com/foo/Main.java <==
/*
 * Copyright (c) 2024, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package com.foo;

import java.lang.module.ModuleDescriptor;
import java.lang.module.ModuleFinder;
import java.util.stream.Stream;

/**
 * Sanity test if SystemModules pre-resolved at link-time for com.foo
 * with main class is loaded properly.
 */
public class Main {
    public static void main(String... args) throws Exception {
        ModuleDescriptor md = Main.class.getModule().getDescriptor();
        System.out.println(md);

        checkMainClass("com.foo", "com.foo.Main");
        checkMainClass("net.foo", "net.foo.Main");
        Stream.of("jdk.httpserver").forEach(mn ->
                ModuleFinder.ofSystem().find(mn).get().descriptor().mainClass()
                            .orElseThrow(() -> new RuntimeException(mn + " no main class"))
        );
    }

    static void checkMainClass(String mn, String mainClass) {
        String cn = ModuleFinder.ofSystem().find(mn).get().descriptor().mainClass().get();
        if (!cn.equals(mainClass)) {
            throw new RuntimeException("Mismatched main class of module " + mn + ": " + cn + " expected: " + mainClass);
        }
    }
}
